==> orthanc-mysql_1.0.orig.tar.xz: OrthancMySQL-1.0/Framework/MySQL/MySQLResult.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017-2018 Osimis S.A., Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#if ORTHANC_ENABLE_MYSQL != 1
#  error MySQL support must be enabled to use this file
#endif

#include "../Common/ResultBase.h"
#include "MySQLStatement.h"

namespace OrthancDatabases
{
  class MySQLResult : public ResultBase
  {
  private:
    MySQLDatabase&   database_;
    MySQLStatement&  statement_;
    bool             done_;

    void Step();

  protected:
    virtual IValue* FetchField(size_t index);
    
  public:
    MySQLResult(MySQLDatabase& db,
                MySQLStatement& statement);

    virtual ~MySQLResult();
    
    virtual bool IsDone() const
    {
      return done_;
    }

    virtual void Next();
  };
}

==> orthanc-mysql_3.0.orig.tar.xz: OrthancMySQL-3.0/Framework/MySQL/MySQLResult.h <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 * Copyright (C) 2017-2020 Osimis S.A., Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation, either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#pragma once

#if ORTHANC_ENABLE_MYSQL != 1
#  error MySQL support must be enabled to use this file
#endif

#include "../Common/ResultBase.h"
#include "MySQLStatement.h"

namespace OrthancDatabases
{
  class MySQLResult : public ResultBase
  {
  private:
    MySQLDatabase&   database_;
    MySQLStatement&  statement_;
    bool             done_;

    void Step();

  protected:
    virtual IValue* FetchField(size_t index) ORTHANC_OVERRIDE;
    
  public:
    MySQLResult(MySQLDatabase& db,
                MySQLStatement& statement);

    virtual ~MySQLResult() ORTHANC_OVERRIDE;
    
    virtual bool IsDone() const ORTHANC_OVERRIDE
    {
      return done_;
    }

    virtual void Next() ORTHANC_OVERRIDE;
  };
}
